==> jc-1.4.0.tar.gz: soot/NullType.h <==
// public class soot.NullType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f0a1b2286e398082 soot_NullType
// @dep_class fdbc627922b0ba72 soot_RefLikeType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_RefLikeType

#include "soot/RefLikeType.h"

#ifndef _JC_soot_NullType_H_
#define _JC_soot_NullType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_NullType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_NullType$sub_refs	_jc_soot_NullType$sub_refs;
typedef struct _jc_soot_NullType$sub_nonrefs	_jc_soot_NullType$sub_nonrefs;
typedef struct _jc_soot_NullType$refs	_jc_soot_NullType$refs;
typedef struct _jc_soot_NullType$nonrefs	_jc_soot_NullType$nonrefs;
typedef struct _jc_soot_NullType$object	_jc_soot_NullType$object;

typedef const struct _jc_soot_NullType$vmethods	_jc_soot_NullType$vmethods;
typedef const struct _jc_soot_NullType$vtable	_jc_soot_NullType$vtable;
typedef const struct _jc_soot_NullType$vtype	_jc_soot_NullType$vtype;

// Constructors
extern void _jc_soot_NullType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_NullType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_object *);
extern jboolean _jc_soot_NullType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_Type$object *_jc_soot_NullType$method$getArrayElementType$15d4b254b1d62067(_jc_env *, struct _jc_soot_NullType$object *);
extern jint _jc_soot_NullType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_NullType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_NullType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_NullType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_NullType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_NullType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_NullType$method_info$getArrayElementType$15d4b254b1d62067;
extern _jc_method _jc_soot_NullType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_NullType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_NullType$object *_jc_soot_NullType$method$v$4cab75308b721566(_jc_env *);

// Virtual methods structure
struct _jc_soot_NullType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_Type$object	*(*getArrayElementType$15d4b254b1d62067)(_jc_env *, struct _jc_soot_NullType$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_NullType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_NullType$object *);
};

// Vtable
struct _jc_soot_NullType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_RefLikeType$vmethods	soot_RefLikeType;
	_jc_soot_NullType$vmethods	soot_NullType;
};

// Vtype
struct _jc_soot_NullType$vtype {
	_jc_type			type;
	_jc_soot_NullType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_NullType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_NullType$refs {
    _jc_soot_NullType$sub_refs	soot_NullType;
    _jc_soot_RefLikeType$sub_refs	soot_RefLikeType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_NullType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_NullType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_RefLikeType$sub_nonrefs	soot_RefLikeType;
    _jc_soot_NullType$sub_nonrefs	soot_NullType;
};

// Object instance structure
struct _jc_soot_NullType$object {
	_jc_soot_NullType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_NullType$vtype	*vtype;
	_jc_soot_NullType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_NullType$vtype _jc_soot_NullType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_NullType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_NullType$class_object;

#endif	/* _JC_soot_NullType_H_ */

==> jc-1.4.6.tar.gz: soot/NullType.h <==
// public class soot.NullType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f0a1b2286e398082 soot_NullType
// @dep_class fdbc627922b0ba72 soot_RefLikeType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_RefLikeType

#include "soot/RefLikeType.h"

#ifndef _JC_soot_NullType_H_
#define _JC_soot_NullType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_NullType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_NullType$sub_refs	_jc_soot_NullType$sub_refs;
typedef struct _jc_soot_NullType$sub_nonrefs	_jc_soot_NullType$sub_nonrefs;
typedef struct _jc_soot_NullType$refs	_jc_soot_NullType$refs;
typedef struct _jc_soot_NullType$nonrefs	_jc_soot_NullType$nonrefs;
typedef struct _jc_soot_NullType$object	_jc_soot_NullType$object;

typedef const struct _jc_soot_NullType$vmethods	_jc_soot_NullType$vmethods;
typedef const struct _jc_soot_NullType$vtable	_jc_soot_NullType$vtable;
typedef const struct _jc_soot_NullType$vtype	_jc_soot_NullType$vtype;

// Constructors
extern void _jc_soot_NullType$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_NullType$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_NullType$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_NullType$method$getArrayElementType$15d4b254b1d62067(_jc_env *, struct _jc_soot_NullType$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_NullType$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_NullType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_NullType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_NullType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_NullType$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_NullType$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_NullType$method_info$getArrayElementType$15d4b254b1d62067;
extern _jc_method _jc_soot_NullType$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_NullType$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_NullType$object *_jc_soot_NullType$method$v$4cab75308b721566(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_NullType$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_NullType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getArrayElementType$15d4b254b1d62067)(_jc_env *, struct _jc_soot_NullType$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_NullType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_NullType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_NullType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_RefLikeType$vmethods	soot_RefLikeType;
	_jc_soot_NullType$vmethods	soot_NullType;
};

// Vtype
struct _jc_soot_NullType$vtype {
	_jc_type			type;
	_jc_soot_NullType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_NullType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_NullType$refs {
    _jc_soot_NullType$sub_refs	soot_NullType;
    _jc_soot_RefLikeType$sub_refs	soot_RefLikeType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_NullType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_NullType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_RefLikeType$sub_nonrefs	soot_RefLikeType;
    _jc_soot_NullType$sub_nonrefs	soot_NullType;
};

// Object instance structure
struct _jc_soot_NullType$object {
	_jc_soot_NullType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_NullType$vtype	*vtype;
	_jc_soot_NullType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_NullType$vtype _jc_soot_NullType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_NullType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_NullType$class_object;

#endif	/* _JC_soot_NullType_H_ */
